import { timerify } from './util/Performance.js';
import parsedArgValues from './util/cli-arguments.js';
import { FileEntryCache } from './util/file-entry-cache.js';
import { cwd, join } from './util/path.js';
import { version } from './version.js';
const defaultCacheLocation = join(cwd, 'node_modules', '.cache', 'knip');
const { cache: isCache = false, watch: isWatch = false } = parsedArgValues;
const cacheLocation = parsedArgValues['cache-location'] ?? defaultCacheLocation;
const dummyFileDescriptor = { key: '', changed: true, notFound: true };
const isEnabled = isCache || isWatch;
export class CacheConsultant {
    cache;
    constructor(name) {
        if (isCache) {
            const cacheName = `${name.replace(/[^a-z0-9]/g, '-').replace(/-*$/, '')}-${version}`;
            this.cache = new FileEntryCache(cacheName, cacheLocation);
            this.reconcile = timerify(this.cache.reconcile).bind(this.cache);
            this.getFileDescriptor = timerify(this.cache.getFileDescriptor).bind(this.cache);
        }
    }
    static getCacheLocation() {
        return cacheLocation;
    }
    getFileDescriptor(file) {
        if (isEnabled && this.cache)
            return this.cache?.getFileDescriptor(file);
        return dummyFileDescriptor;
    }
    reconcile() {
        if (isEnabled && this.cache)
            this.cache.reconcile();
    }
}
